@@ -146,15 +146,15 @@ function install() {
         return 1
     fi
 
-    cp ./src/{SoapLism.pm,lism.cgi,soaplism.conf} /var/www/cgi-bin/
+    cp ./src/{SoapLism.pm,lism.cgi,lismapi.conf} /var/www/cgi-bin/
     cp ./src/saml_sp.php /var/www/lib/
     cp ./src/idsync /opt/secioss/sbin/
     cp ./conf/config.ini /var/www/conf/
     cp ./conf/config.php /usr/share/simplesamlphp/config/
     cp ./conf/saml20* /usr/share/simplesamlphp/metadata/
     chown ldap.apache /opt/secioss/etc/lism.conf
-    cp ./conf/lism-sp.conf /opt/secioss/etc/
-    chown ldap.apache /opt/secioss/etc/lism-sp.conf
+    cp ./conf/{lism.conf,lism-sp.conf,sugarcrm-userpref.txt} /opt/secioss/etc/
+    chown ldap.apache /opt/secioss/etc/{lism.conf,lism-sp.conf,sugarcrm-userpref.txt}
     chown apache /opt/secioss/var/lib/ldap
     chmod 770 /opt/secioss/var/lib/ldap
     if [ ! -d /opt/secioss/var/lib/csv ]; then
@@ -228,7 +228,7 @@ function update() {
 }
 
 function uninstall() {
-    rm /var/www/cgi-bin/{SoapLism.pm,lism.cgi,soaplism.conf}
+    rm /var/www/cgi-bin/{SoapLism.pm,lism.cgi,lismapi.conf}
     rm /var/www/lib/saml_sp.php
     rm /opt/secioss/sbin/idsync
 
